==> php-4.3.9.tar.bz2: php-4.3.9/win32/pwd.c <==
/*
   +----------------------------------------------------------------------+
   | PHP Version 4                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2003 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 2.02 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available at through the world-wide-web at                           |
   | http://www.php.net/license/2_02.txt.                                 |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Sterling Hughes <sterling@php.net>                           |
   +----------------------------------------------------------------------+
*/

/* $Id: pwd.c,v 1.5.4.2 2004/07/30 14:37:17 wez Exp $ */

#include "php.h"				/*php specific */
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <lmaccess.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <lmapibuf.h>
#include "pwd.h"
#include "grp.h"
#include "php_win32_globals.h"

static char *home_dir = ".";
static char *login_shell = "not command.com!";

struct passwd *
getpwnam(char *name)
{
	return (struct passwd *) 0;
}


char *
getlogin()
{
	char name[256];
	DWORD max_len = 256;
	TSRMLS_FETCH();

	STR_FREE(PW32G(login_name));	
	GetUserName(name, &max_len);
	name[max_len] = '\0';
	PW32G(login_name) = strdup(name);
	return PW32G(login_name);
}

struct passwd *
getpwuid(int user_id)
{
	TSRMLS_FETCH();
	PW32G(pwd).pw_name = getlogin();
	PW32G(pwd).pw_dir = home_dir;
	PW32G(pwd).pw_shell = login_shell;
	PW32G(pwd).pw_uid = 0;

	return &PW32G(pwd);
}

==> php-4.4.4.tar.bz2: php-4.4.4/win32/pwd.c <==
/*
   +----------------------------------------------------------------------+
   | PHP Version 4                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2006 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_01.txt                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Sterling Hughes <sterling@php.net>                           |
   +----------------------------------------------------------------------+
*/

/* $Id: pwd.c,v 1.5.4.3.2.1 2006/01/01 13:47:02 sniper Exp $ */

#include "php.h"				/*php specific */
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <lmaccess.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <lmapibuf.h>
#include "pwd.h"
#include "grp.h"
#include "php_win32_globals.h"

static char *home_dir = ".";
static char *login_shell = "not command.com!";

struct passwd *
getpwnam(char *name)
{
	return (struct passwd *) 0;
}


char *
getlogin()
{
	char name[256];
	DWORD max_len = 256;
	TSRMLS_FETCH();

	STR_FREE(PW32G(login_name));	
	GetUserName(name, &max_len);
	name[max_len] = '\0';
	PW32G(login_name) = estrdup(name);
	return PW32G(login_name);
}

struct passwd *
getpwuid(int user_id)
{
	TSRMLS_FETCH();
	PW32G(pwd).pw_name = getlogin();
	PW32G(pwd).pw_dir = home_dir;
	PW32G(pwd).pw_shell = login_shell;
	PW32G(pwd).pw_uid = 0;

	return &PW32G(pwd);
}
